@@ -1,13 +1,16 @@
 # -*- coding: utf-8 -*-
+
 import re
 import string
 
-VERB, NOUN, ADJECTIVE, ADVERB = "VB", "NN", "JJ", "RB"
+PUNCTUATION_REGEX = re.compile('[{0}]'.format(re.escape(string.punctuation)))
+
 
 def strip_punc(s):
     '''Removes punctuation from a string.'''
-    return s.translate(string.maketrans("", ""), string.punctuation)
+    return PUNCTUATION_REGEX.sub('', s)
+
 
 def lowerstrip(s):
     '''Makes text all lowercase and strips punctuation and whitespace.'''
-    return strip_punc(s.lower().strip())
\ No newline at end of file
+    return strip_punc(s.lower().strip())
